@@ -125,7 +125,7 @@ def choose_editor(default=None):
             question("Which code editor do you want to use?"),
             default=default
         )
-        if editor_installed(ed) or ed in ['atom', 'subl', 'charm']:
+        if editor_installed(ed) or ed in ['atom', 'subl', 'charm', 'mate', 'code']:
             return ed
         click.echo(error(f"Couldn't find {ed}. Double-check that it's installed."))
 
@@ -226,6 +226,24 @@ class InstallXCode(SetupTask):
         click.echo(address(msg))
         run("xcode-select --install", shell=True, check=True)
 
+class InstallPoetry(SetupTask):
+    description = "Install poetry"
+
+    def is_complete(self):
+        return self.executable_on_path("poetry")
+
+    def run_task(self):
+        shell = get_shell_name()
+        click.echo(address("Installing poetry..."))
+        run("curl -sSL https://install.python-poetry.org | python3 -", shell=True, check=True)
+        click.echo(address("Installing poetry tab completions..."))
+        if shell == "bash":
+            Path("/etc/bash_completion.d").mkdir(exist_ok=True)
+            run("poetry completions bash > /etc/bash_completion.d/poetry", shell=True, check=True)
+        if shell == "zsh":
+            Path("~/.zfunc").mkdir(exist_ok=True)
+            run("poetry completions zsh > ~/.zfunc/_poetry", shell=True, check=True)
+
 class WriteShellConfig(SetupTask):
     description = "Write the MWC shell configuration file ~/.mwc_rc"
 
@@ -281,9 +299,6 @@ class InstallPackage(SetupTask):
 class InstallPython3(InstallPackage):
     package_name = brew_name = apt_name = "python3"
 
-class InstallPoetry(InstallPackage):
-    package_name = brew_name = apt_name = "poetry"
-
 class InstallGit(InstallPackage):
     package_name = brew_name = apt_name = "git"
 
@@ -300,6 +315,9 @@ class InstallGh(InstallPackage):
     def package_installer(self):
         return "brew"
 
+class InstallImageMagick(InstallPackage):
+    package_name = brew_name = apt_name = "imagemagick"
+
 class GHAuthentication(SetupTask):
     description = "Sign in to github"
     gh_auth_file = Path.home() / ".config/gh/hosts.yml"
@@ -319,5 +337,38 @@ class GHAuthentication(SetupTask):
         else:
             return {}
 
-#class GitConfiguration(SetupTask):
-    #"git config --global init.defaultBranch <name>"
+class GitConfiguration(SetupTask):
+    """Configure global git settings.
+    Can be skipped by setting `skip_git_config: true` in settings.
+    """
+
+    editorcmds = {
+        "atom": "atom --wait",
+        "code": "code --wait",
+        "subl": "subl -n -w",
+        "mate": "mate -w",
+        "vim": "vim",
+        "emacs": "emacs",
+    }
+
+    def is_complete(self):
+        return self.settings.get("skip_git_config")
+
+    def run_task(self):
+        git_settings = {
+            "init.defaultBranch": "main",
+            "commit.template": ".commit_template",
+        }
+        if self.settings.get('editor') in self.editorcmds:
+            editorcmd = self.editorcmds[self.settings.get('editor')]
+            git_settings["core.editor"] = f'"{editorcmd}"'
+        if self.settings.get('git_name'):
+            git_settings["user.name"] = self.settings['git_name']
+        if self.settings.get('github_email'):
+            git_settings["user.email"] = self.settings['github_email']
+        for key, val in git_settings.items():
+            run(f"git config --global {key} {val}", shell=True, check=True)
+
+
+
+
