@@ -15,6 +15,24 @@ class GithubBackend(GitBackend):
     within scope.
     """
 
+    @classmethod
+    def extend_settings(self, settings):
+        "Asks for the user's github username and email address"
+        def choose_github_username(github_username):
+            msg = "What is your GitHub username? "
+            return click.prompt(msg, default=github_username)
+        def choose_github_email(github_email):
+            msg = "What is the email address associated with your GitHub account? "
+            return click.prompt(msg, default=github_username)
+        def choose_git_name(git_name):
+            msg = "What name do you want to use in your git commits? "
+            return click.prompt(msg, default=git_name)
+        if click.confirm("Do you have a GitHub account?"):
+            settings['github_username'] = choose_github_username(settings.get("github_username"))
+            settings['github_email'] = choose_github_email(settings.get("github_email"))
+            settings['git_name'] = choose_git_name(settings.get("git_name"))
+        return settings
+
     def init_clone(self, module, modpath):
         url = module["repo_url"]
         cmd = f'gh repo clone "{url}" "{modpath.name}"'
